/**
 * @(#) ComponentLifeCycle.java
 *
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: ComponentLifeCycle.java 69 2006-01-17 16:00:26Z rmarins $
 * -------------------------------------------------------------------------
 */

//
// This source code implements specifications defined by the Java
// Community Process. In order to remain compliant with the specification
// DO NOT add / change / or delete method signatures!
//

package javax.jbi.component;

/**
 * This interface must be implemented by a JBI component to provide
 * initialization, start, stop, and shutdown life cycle processing. These
 * methods comprise the life cycle contract between the JBI implementation and
 * the component. The life cycle of a component begins with a call to the init()
 * method on an instance of the component’s implementation of this interface,
 * and ends with the first call to the shutDown() method on that instance.
 * Between these two calls, there can be any number of stop() and start() calls.
 * <p>
 * The JBI implementation must track the running state of a component, and
 * ensure that life cycle state changes are always legal. For example, if the
 * management interface for controlling a component's life cycle (
 * {@link javax.jbi.management.ComponentLifeCycleMBean})
 * is used to start a component that was just installed (and thus in the
 * <i>Shutdown</i> state), the implementation must invoke this component's
 * {@link ComponentLifeCycle#init(ComponentContext)} method before invoking its
 * {@link ComponentLifeCycle#start()} method.
 * 
 * @author JSR208 Expert Group
 */
public interface ComponentLifeCycle {

	/**
	 * Get the JMX object name for the extension MBean for this component; if
	 * there is none, return <code>null</code>.
	 * 
	 * @return the JMX object name of the additional MBean or <code>null</code>
	 *         if there is no additional MBean.
	 */
	public javax.management.ObjectName getExtensionMBeanName();

	/**
     * Initialize the component. This performs initialization required by the
     * component but does not make it ready to process messages. This method is
     * called once for each life cycle of the component.
     * <p>
     * If the component needs to register an additional MBean to extend its life
     * cycle, or provide other component management tasks, it should be
     * registered during this call.
     * 
     * @param context
     *            the component's context, providing access to component data
     *            provided by the JBI environment; must be non-null
     * @throws javax.jbi.JBIException
     *             if the component is unable to initialize.
     */
	public void init(javax.jbi.component.ComponentContext context)
			throws javax.jbi.JBIException;

	/**
     * Shut down the component. This performs clean-up, releasing all run-time
     * resources used by the component. Once this method has been called, 
     * {@link ComponentLifeCycle#init(ComponentContext)} must be called before
     * the component can be started again with a call to
     * {@link ComponentLifeCycle#start()}.
     * 
     * @throws javax.jbi.JBIException
     *             if the component is unable to shut down
     */
	public void shutDown() throws javax.jbi.JBIException;

	/**
     * Start the component. This makes the component ready to process messages.
     * This method is called after
     * {@link ComponentLifeCycle#init(ComponentContext)}, both when the
     * component is being started for the first time and when the component is
     * being restarted after a previous call to
     * {@link ComponentLifeCycle#shutDown()}. If
     * {@link ComponentLifeCycle#stop()} was called previously but
     * {@link ComponentLifeCycle#shutDown()} was not,
     * {@link ComponentLifeCycle#start()} can be called again without another
     * call to {@link ComponentLifeCycle#init(ComponentContext)}.
     * 
     * @throws javax.jbi.JBIException
     *             if the component is unable to start.
     */
	public void start() throws javax.jbi.JBIException;

	/**
     * Stop the component. This makes the component stop accepting messages for
     * processing. After a call to this method,
     * {@link ComponentLifeCycle#start()} can be called again without first
     * calling {@link ComponentLifeCycle#init(ComponentContext)}.
     * 
     * @throws javax.jbi.JBIException
     *             if the component is unable to stop
     */
	public void stop() throws javax.jbi.JBIException;
}
